@@ -43,6 +43,7 @@ class Simulation(CoreSimulation):
 
     calculated_periods: List[str] = []
     _variable_dependencies: Dict[str, List[str]] = None
+    dataset = None
 
     def __init__(
         self,
@@ -70,12 +71,6 @@ class Simulation(CoreSimulation):
         if reform is not None:
             scenario = Scenario.from_reform(reform)
 
-        # Apply parametric reforms here
-
-        if scenario is not None:
-            if scenario.parameter_changes is not None:
-                self.apply_parameter_changes(scenario.parameter_changes)
-
         self.branch_name = "default"
         self.invalidated_caches = set()
         self.debug: bool = False
@@ -90,6 +85,12 @@ class Simulation(CoreSimulation):
 
         self.branches: Dict[str, Simulation] = {}
 
+        if scenario is not None and scenario.applied_before_data_load:
+            if scenario.simulation_modifier is not None:
+                scenario.simulation_modifier(self)
+
+            if scenario.parameter_changes is not None:
+                self.apply_parameter_changes(scenario.parameter_changes)
         # Build simulation from appropriate source
         if situation is not None:
             self.build_from_situation(situation)
@@ -110,8 +111,6 @@ class Simulation(CoreSimulation):
         else:
             raise ValueError(f"Unsupported dataset type: {dataset.__class__}")
 
-        self.input_variables = self.get_known_variables()
-
         # Universal Credit reform (July 2025). Needs closer integration in the baseline,
         # but adding here for ease of toggling on/off via the 'active' parameter.
         from policyengine_uk.scenarios import universal_credit_july_2025_reform
@@ -122,9 +121,10 @@ class Simulation(CoreSimulation):
 
         self.tax_benefit_system.reset_parameter_caches()
 
-        if scenario is not None:
-            if scenario.simulation_modifier is not None:
-                scenario.simulation_modifier(self)
+        self.move_values("capital_gains", "capital_gains_before_response")
+        self.move_values("employment_income", "employment_income_before_lsr")
+
+        self.input_variables = self.get_known_variables()
 
         if scenario is not None:
             self.baseline = Simulation(
@@ -138,6 +138,12 @@ class Simulation(CoreSimulation):
 
         self.calculated_periods = []
 
+        if scenario is not None and not scenario.applied_before_data_load:
+            if scenario.simulation_modifier is not None:
+                scenario.simulation_modifier(self)
+            if scenario.parameter_changes is not None:
+                self.apply_parameter_changes(scenario.parameter_changes)
+
     def reset_calculations(self):
         for variable in self.tax_benefit_system.variables:
             if variable not in self.input_variables:
@@ -322,7 +328,9 @@ class Simulation(CoreSimulation):
         dataset = UKSingleYearDataset.from_simulation(
             self, fiscal_year=first_time_period
         )
-        multi_year_dataset = extend_single_year_dataset(dataset)
+        multi_year_dataset = extend_single_year_dataset(
+            dataset, self.tax_benefit_system.parameters
+        )
 
         self.build_from_multi_year_dataset(multi_year_dataset)
         self.dataset = multi_year_dataset
@@ -336,7 +344,9 @@ class Simulation(CoreSimulation):
             dataset: UKSingleYearDataset containing one year of data
         """
 
-        dataset = extend_single_year_dataset(dataset)
+        dataset = extend_single_year_dataset(
+            dataset, self.tax_benefit_system.parameters
+        )
         self.build_from_multi_year_dataset(dataset)
         self.dataset = dataset
 
