@@ -26,12 +26,10 @@ class gov_tax(Variable):
         "national_insurance",
         "LVT",
         "carbon_tax",
-        "vat_change",
         "capital_gains_tax",
         "private_school_vat",
         "corporate_incident_tax_revenue_change",
         "consumer_incident_tax_revenue_change",
-        "high_income_incident_tax_change",
         "ni_employer",
         "student_loan_repayments",
         "vat",
